@@ -48,11 +48,7 @@ if TYPE_CHECKING:
 
 
 class AIOForeignKeyAccessor(ForeignKeyAccessor):
-    def get_rel_instance(
-        self,
-        instance: Model,
-    ) -> Union[Model, None, Coroutine[Any, Any, Model]]:
-
+    async def get_rel_instance(self, instance: AIOModel) -> Optional[AIOModel]:
         # Get from cache
         name = self.name
         if name in instance.__rel__:
@@ -64,21 +60,17 @@ class AIOForeignKeyAccessor(ForeignKeyAccessor):
         field = self.field
         if field.lazy_load:
             if value is not None:
-                return self.load_rel(instance, value)
+                obj = await self.rel_model.get(self.field.rel_field == value)
+                instance.__rel__[self.name] = obj
+                return obj
 
             if not field.null:
                 raise self.rel_model.DoesNotExist
 
         return value
 
-    async def load_rel(self, instance: Model, value: Any) -> Model:
-        obj = await self.rel_model.get(self.field.rel_field == value)
-        instance.__rel__[self.name] = obj
-        return obj
-
 
 class AIOForeignKeyField(ForeignKeyField):
-
     accessor_class = AIOForeignKeyAccessor
 
 
@@ -89,7 +81,6 @@ class AIODeferredForeignKey(DeferredForeignKey):
 
 
 class AIOModelBase(ModelBase):
-
     inheritable = ModelBase.inheritable & {"manager"}
 
     def __new__(cls, name, bases, attrs):
@@ -148,7 +139,6 @@ class AIOModelBase(ModelBase):
 
 
 class AIOModel(Model, metaclass=AIOModelBase):
-
     _manager: Manager
 
     # Class methods
@@ -249,17 +239,19 @@ class AIOModel(Model, metaclass=AIOModelBase):
         rows: Iterable,
         fields=None,
     ) -> AIOModelInsert[TVAIOModel]:
-        rows = [row.__data__ if isinstance(row, Model) else row for row in rows]
         if not rows:
             raise AIOModelInsert.DefaultValuesException("Error: no rows to insert.")
 
+        rows = [row.__data__ if isinstance(row, Model) else row for row in rows]
         return AIOModelInsert(cls, insert=rows, columns=fields)
 
     @classmethod
-    def insert_from(cls: Type[TVAIOModel], query, fields) -> AIOModelInsert[TVAIOModel]:
-        columns = [
-            getattr(cls, field) if isinstance(field, str) else field for field in fields
-        ]
+    def insert_from(
+        cls: Type[TVAIOModel],
+        query: ModelSelect,
+        fields,
+    ) -> AIOModelInsert[TVAIOModel]:
+        columns = [getattr(cls, field) if isinstance(field, str) else field for field in fields]
         return AIOModelInsert(cls, insert=query, columns=columns)
 
     @classmethod
@@ -290,7 +282,6 @@ class AIOModel(Model, metaclass=AIOModelBase):
 
 
 class AIOQuery(Generic[TVAIOModel]):
-
     model: Type[TVAIOModel]
 
     def __init__(self, *args, **kwargs):
